#include <WScom.h>
#include <WSCfunctionList.h>
#include <WSCbase.h>

/**/

#include "Common.h"

/**/

extern WSCdialog *Cnfdial_ConfigUrl;

/**/

//----------------------------------------------------------
//Function for the event procedure
//----------------------------------------------------------
void MainMenuCnfUrl(WSCbase* object){
  //do something...
	Cnfdial_ConfigUrl->execProcedure( "CnfWinInit" );
	long n = Cnfdial_ConfigUrl->popup();

	if( n == WS_DIALOG_OK ){
		gHeadLine.SaveUrl();
	} else {
		if( !gHeadLine.LoadUrl() )
			gHeadLine.ResetUrlList();
	}
}
static WSCfunctionRegister  op("MainMenuCnfUrl",(void*)MainMenuCnfUrl);
